# runtime.async_ops

## Purpose
Domain runtime primitives for async_ops.

## Owns
- Modules under `vyro.runtime.async_ops`.

## Entry Points
- `vyro.runtime.async_ops`

## Not Here
- Public app composition (`vyro.app`).
